<?php
namespace Drupal\browser_development\Form\Develop;

use Drupal\Core\Form\FormBase;
use Drupal\Core\Form\FormStateInterface;

use Drupal\browser_development\Processing\Scss;
use Drupal\browser_development\Processing\Storage;


/**
 * Class Page.
 *
 *
 */
class Page extends FormBase {


  protected $number = 1;

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'develop_page';
  }
  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {

    $data = Storage::getStorage()['parent'];

    $form['#tree'] = TRUE;

    $form['container'] = [
      '#type'       => 'container',
      '#attributes' => ['id' => 'browser-development-container-component'], // CHECK THIS ID
    ];

    $form['container']['build_css_scss'] = [
        '#type'       => 'checkbox',
        '#title' => $this->t('SCSS format'),
        '#default_value' =>  $data[0]['build_css_scss']
    ];

    unset($data[0]);
    $this->number = count($data) +1;


    for ($i = 1; $i <= $this->number; $i++) {
         $form['container']['build_css_' . $i] = [
          '#type' => 'details',
          '#title' => t('Component'),
          '#open' => TRUE,
         ];

        $form['container']['build_css_' . $i]['label'] = [
          '#type'       => 'textfield',
          '#attributes' => ['placeholder' => $this->t('Label')],
          '#size'       => 20,
          '#required'   => TRUE,
          '#default_value' => $data[$i]['build_css_' . $i]['label']
        ];

        $form['container']['build_css_' . $i]['css'] = [
          '#type' => 'textarea',
          '#attributes' => ['placeholder' => $this->t('css or scss')],
          '#required'   => TRUE,
          '#default_value' => $data[$i]['build_css_' . $i]['css']
        ];
     }

    // Disable caching on this form.
    $form_state->setCached(FALSE);

    $form['container']['actions'] = [
      '#type' => 'actions',
    ];

    /*
     * The #ajax attribute used in the temperature input element defines an ajax
     * callback that will invoke the colorCallback method on this form object.
     * Whenever the temperature element changes, it will invoke this callback
     * and replace the contents of the color_wrapper container with the results
     * of this method call.
     */

    /* Something wrong with ajax call back and access a new form element this will need to be resolve in the future
    $form['container']['actions']['add_item'] = [
      '#type'   => 'submit',
      '#value'  => $this->t('New'),
      '#submit' => ['::browser_development_develop_page_add_item'],
      '#ajax'   => [
        // Could also use [ $this, 'colorCallback'].
        'callback' => '::browser_development_develop_page_ajax_callback',
        'wrapper'  => 'browser-development-container-component', // CHECK THIS ID
      ],
    ];

    if ($this->number > 1) {

      $form['container']['actions']['remove_item'] = [
        '#type'                    => 'submit',
        '#value'                   => $this->t('Remove'),
        '#submit'                  => ['::browser_development_develop_page_remove_item'],
        // Since we are removing a name, don't validate until later.
        '#limit_validation_errors' => [],
        '#ajax'                    => [
          'callback' => '::browser_development_develop_page_ajax_callback',
          'wrapper'  => 'browser-development-container-component', // CHECK THIS ID
        ],
      ];
    }
     */

     $form['container']['actions']['submit'] = array(
       '#type'  => 'submit',
       '#value' => $this->t('Build'),
     );


     $form['preview'] = [
      '#type'       => 'container',
      '#attributes' => ['id' => 'preview-container'], // CHECK THIS ID
    ];

    return $form;
  }


 /**
   * Implements callback for Ajax event on color selection.
   *
   * @param array $form
   *   From render array.
   * @param \Drupal\Core\Form\FormStateInterface $form_state
   *   Current state of form.
   *
   * @return array
   *   Color selection section of the form.
   */
  public function browser_development_develop_page_ajax_callback($form, $form_state) {
    //┆Storage::setStorage($form_state->getValues()['container']);
    return $form['container'];
  }

  public function browser_development_develop_page_add_item(array &$form, FormStateInterface $form_state) {

    $this->number++;
    $form_state->setRebuild();
  }

  public function browser_development_develop_page_remove_item(array &$form, FormStateInterface $form_state) {

    if ($this->number > 1) {
      $this->number--;
    }
    $form_state->setRebuild();
  }



  /**
   * {@inheritdoc}
   */
  public function validateForm(array &$form, FormStateInterface $form_state) {
    parent::validateForm($form, $form_state);
  }
  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
     Storage::setStorage($form_state->getValues()['container']);
   //  \Drupal::messenger()->addMessage(Scss::getProcessedOutput('sss'));
  }
}
